package codelet;

import org.openqa.selenium.WebDriver;
import org.openqa.selenium.firefox.FirefoxDriver;
import org.openqa.selenium.firefox.FirefoxOptions;
import org.openqa.selenium.firefox.FirefoxProfile;
import org.w3c.dom.Document;
import org.w3c.dom.NodeList;
import util.PathExtractorForWebDriver;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import java.io.File;
import java.util.concurrent.TimeUnit;

public class WebDriverFactory {

    public static WebDriver webDriverFactoryFireFox(String pathToGeckoDriver) throws Exception{

        //set language and properties of Webbrowser
        FirefoxProfile profile = new FirefoxProfile();
        profile.setPreference("intl.accept_languages","en");
        FirefoxOptions options = new FirefoxOptions();
        options.setProfile(profile);
        options.setCapability("marionette", true);

        WebDriver driver = null;

        //try to get driver from path-var
        try{
            driver = new FirefoxDriver(options);
            if(driver != null){
                System.out.println("Gecko-Driver was found in systems path variable.");
            }
        } catch (Exception e){
            System.out.println("No Gecko-Driver was found in systems path variable. Continue with search in user directory.");
        }

        //try to get driver from xml file in user directory
        if(driver  == null){
            try {
                String configFilePath = getGeckoDriverPathFromUserDirectoryInConfigXML();
                System.setProperty("webdriver.gecko.driver", configFilePath);
                driver = new FirefoxDriver(options);
                System.out.println("Gecko-Driver was found in user directory.");

            } catch (Exception e){
                System.out.println("No Gecko-Driver was found in user directory. Continue with search in yawl parameter.");
            }
        }

        //try to get driver from yawl parameter
        if(driver == null){
            try{
                System.setProperty("webdriver.gecko.driver", pathToGeckoDriver);
                driver = new FirefoxDriver(options);
                if(driver != null){
                    System.out.println("Gecko-Driver was found with yawl parameter.");
                }
            } catch (Exception e){
                System.out.println("No Gecko-Driver was found with yawl parameter. Gecko driver can not be found, script will be cancelled.");
            }
        }

        //if not there, there is no gecko driver at all -> throw exception
        if(driver == null){
            throw new Exception("No Gecko-Driver was found with yawl parameter. Gecko driver can not be found, script will be cancelled.");
        }

        driver.manage().timeouts().implicitlyWait(6, TimeUnit.SECONDS);
        driver.manage().timeouts().pageLoadTimeout(6, TimeUnit.SECONDS);
        driver.manage().timeouts().setScriptTimeout(6, TimeUnit.SECONDS);

        return driver;

    }

    public static String getGeckoDriverPathFromUserDirectoryInConfigXML() {

        String resultPath = "";
        //Save Path to config XML file for extracting the needed file path
        // String dir = System.getProperty("user.dir");
        //String dir = "C:\\Users\\Simon\\Documents\\YAWL-4.2\\controlpanel";
        String geckoConfigXMLPath = System.getProperty("user.home") + File.separator + ".GeckoConfigYAWL" + File.separator + "GeckoConfig.xml";

        //load xml config file for extracting geckoDriver path
        File xmlFile = new File(geckoConfigXMLPath);
        DocumentBuilderFactory dbFactory = DocumentBuilderFactory.newInstance();
        DocumentBuilder dBuilder;

        //some XML management
        try {
            dBuilder = dbFactory.newDocumentBuilder();
            Document doc = dBuilder.parse(xmlFile);
            doc.getDocumentElement().normalize();
            doc.getDocumentElement().getChildNodes().item(0).getTextContent();
            NodeList nodeList = doc.getElementsByTagName("GeckoDriverFilePath");
            resultPath = doc.getDocumentElement().getChildNodes().item(1).getTextContent();

        } catch (Exception e) {
            System.out.println("No gecko driver found in config xml because " + e.getMessage());
        }

        return resultPath;

    }
}
