package util;

import exceptions.NoGeckoDriverFoundException;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.firefox.FirefoxDriver;
import org.openqa.selenium.firefox.FirefoxOptions;
import org.openqa.selenium.firefox.FirefoxProfile;


import java.util.concurrent.TimeUnit;

public class WebDriverFactory {

    public static WebDriver webDriverFactoryFireFox(String pathToGeckoDriver) throws NoGeckoDriverFoundException{

        //set language and properties of Webbrowser
        FirefoxProfile profile = new FirefoxProfile();
        profile.setPreference("intl.accept_languages","en");
        FirefoxOptions options = new FirefoxOptions();
        options.setProfile(profile);
        options.setCapability("marionette", true);

        WebDriver driver = null;

        //try to get driver from path-var
        try{
            driver = new FirefoxDriver(options);
            if(driver != null){
                System.out.println("Gecko-Driver was found in systems path variable.");
            }
        } catch (Exception e){
            System.out.println("No Gecko-Driver was found in systems path variable. Continue with search in user directory.");
        }

        //try to get driver from xml file in user directory
        if(driver  == null){
            try {
                String configFilePath = PathExtractorForWebDriver.getGeckoDriverPathFromUserDirectoryInConfigXML();
                System.setProperty("webdriver.gecko.driver", configFilePath);
                driver = new FirefoxDriver(options);
                System.out.println("Gecko-Driver was found in user directory.");

            } catch (Exception e){
                System.out.println("No Gecko-Driver was found in user directory. Continue with search in yawl parameter.");
            }
        }

        //try to get driver from yawl parameter
        if(driver == null){
            try{
                System.setProperty("webdriver.gecko.driver", pathToGeckoDriver);
                driver = new FirefoxDriver(options);
                if(driver != null){
                    System.out.println("Gecko-Driver was found with yawl parameter.");
                }
            } catch (Exception e){
                System.out.println("No Gecko-Driver was found with yawl parameter. Gecko driver can not be found, script will be cancelled.");
            }
        }

        //if not there, there is no gecko driver at all -> throw exception
        if(driver == null){
            throw new NoGeckoDriverFoundException("No Gecko-Driver was found with yawl parameter. Gecko driver can not be found, script will be cancelled.");
        }

        driver.manage().timeouts().implicitlyWait(3, TimeUnit.SECONDS);
        driver.manage().timeouts().pageLoadTimeout(3, TimeUnit.SECONDS);
        driver.manage().timeouts().setScriptTimeout(3, TimeUnit.SECONDS);

        return driver;

    }
}
